AssetGroupMessage class

Asset ids grouped under an entity id.

Constructors

AssetGroupMessage({required String entityId, required List<String> assetIds})

Properties

assetIds ↔ List<String>
getter/setter pair
entityId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → AssetGroupMessage