AssetMessage class

Mirrors MediaIntelligenceImageAsset / MediaIntelligenceVideoAsset with a file URL.

Constructors

AssetMessage({required String id, required String path})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → AssetMessage