FaceGroupMessage class

Faces grouped under one key: an asset id or an entity id.

Constructors

FaceGroupMessage({required String key, required List<FaceMessage> faces})

Properties

faces ↔ List<FaceMessage>
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → FaceGroupMessage