FaceMessage class

Mirrors FaceGroupAnalyzer.Face.

Constructors

FaceMessage({required String id, required String assetId, String? entityId, required double x, required double y, required double width, required double height})

Properties

assetId ↔ String
getter/setter pair
entityId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
height ↔ double
getter/setter pair
id ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → FaceMessage