MediaIntelligenceHostApi class

Registered only on iOS 27 / macOS 27 and later.

Constructors

MediaIntelligenceHostApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for MediaIntelligenceHostApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger → BinaryMessenger?
final
pigeonVar_messageChannelSuffix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allAssetIds(int handle) → Future<List<String>>
allAssetIdsByEntity(int handle) → Future<List<AssetGroupMessage>>
allEntityIds(int handle) → Future<List<String>>
allFaces(int handle) → Future<List<FaceMessage>>
allFacesByEntity(int handle) → Future<List<FaceGroupMessage>>
analyzeVideo(AssetMessage asset, bool highlights, bool keyFrame) → Future<VideoAnalysisMessage>
assetIdsForEntities(int handle, List<String> entityIds) → Future<List<AssetGroupMessage>>
cancel(int requestId) → Future<void>
Stops routing results for requestId. The framework may still finish the work.
deleteAllAssets(int handle) → Future<void>
deleteAssets(int handle, List<String> assetIds) → Future<void>
faceGroupState(int handle) → Future<FaceGroupStateMessage>
facesForEntities(int handle, List<String> entityIds) → Future<List<FaceGroupMessage>>
facesInAssets(int handle, List<String> assetIds) → Future<List<FaceGroupMessage>>
facesWithIds(int handle, List<String> faceIds) → Future<List<FaceMessage>>
liveHandleCount() → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFaceGroupAnalyzer(String workingDirectory) → Future<int>
purgeFaceGroups(String workingDirectory) → Future<void>
release(int handle) → Future<void>
releaseAll() → Future<int>
startIdentifyFaces(int handle, int requestId, List<AssetMessage> assets) → Future<void>
Like startInsertOrUpdateAssets, without adding the assets.
startInsertOrUpdateAssets(int handle, int requestId, List<AssetMessage> assets) → Future<void>
Starts adding or re-analyzing assets. Returns once started; one onAssetFaces per asset follows, then onComplete or onError.
toString() → String
A string representation of this object.
inherited
updateFaceGroups(int handle) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>