RequestErrorMessage class
A failure of one video request, while others may succeed.
Constructors
- RequestErrorMessage({required String code, required String message, String? details})
Properties
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → RequestErrorMessage