TimeRangeMessage class

A time range in seconds.

Constructors

TimeRangeMessage({required double startSeconds, required double durationSeconds})

Properties

durationSeconds ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startSeconds ↔ double
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → TimeRangeMessage