VideoAnalysisMessage class

The results of VideoAnalyzer.analyze. A requested analysis has either its result fields or its error set.

Constructors

VideoAnalysisMessage({List<TimeRangeMessage>? highlights, List<HighlightLevelMessage>? highlightLevels, RequestErrorMessage? highlightError, double? keyFrameSeconds, RequestErrorMessage? keyFrameError})

Properties

hashCode → int
The hash code for this object.
no setteroverride
highlightError ↔ RequestErrorMessage?
getter/setter pair
highlightLevels ↔ List<HighlightLevelMessage>?
getter/setter pair
highlights ↔ List<TimeRangeMessage>?
getter/setter pair
keyFrameError ↔ RequestErrorMessage?
getter/setter pair
keyFrameSeconds ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → VideoAnalysisMessage