MediaIntelligenceCallbackApi class abstract
Native → Dart events for streaming face requests.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAssetFaces(
int requestId, FaceGroupMessage assetFaces) → void -
onComplete(
int requestId) → void -
onError(
int requestId, RequestErrorMessage error) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setUp(
MediaIntelligenceCallbackApi? api, {BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''}) → void
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>